<?php

namespace Superrobota\Business\Policies;

use Litepie\User\Contracts\UserPolicy;
use Superrobota\Business\Models\Business;

class BusinessPolicy
{

    /**
     * Determine if the given user can view the business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function view(UserPolicy $user, Business $business)
    {
        if ($user->canDo('business.business.view') && $user->isAdmin()) {
            return true;
        }

        return $business->user_id == user_id() && $business->user_type == user_type();
    }

    /**
     * Determine if the given user can create a business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('business.business.create');
    }

    /**
     * Determine if the given user can update the given business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function update(UserPolicy $user, Business $business)
    {
        if ($user->canDo('business.business.edit') && $user->isAdmin()) {
            return true;
        }

        return $business->user_id == user_id() && $business->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Business $business)
    {
        return $business->user_id == user_id() && $business->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Business $business)
    {
        if ($user->canDo('business.business.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given business.
     *
     * @param UserPolicy $user
     * @param Business $business
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Business $business)
    {
        if ($user->canDo('business.business.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
